@@ -1,9 +1,10 @@
-package Dist::Zilla::Plugin::Test::PodSpelling;
-use 5.010;
+package Dist::Zilla::Plugin::Test::PodSpelling; # git description: v2.006008-9-g8c27c83
+# vim: ts=4 sts=4 sw=4 et :
+
 use strict;
 use warnings;
 
-our $VERSION = '2.006008'; # VERSION
+our $VERSION = '2.006009';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -169,6 +170,96 @@ no Moose;
 
 # ABSTRACT: Author tests for POD spelling
 
+#pod =for Pod::Coverage gather_files
+#pod
+#pod =head1 SYNOPSIS
+#pod
+#pod In C<dist.ini>:
+#pod
+#pod 	[Test::PodSpelling]
+#pod
+#pod or:
+#pod
+#pod 	[Test::PodSpelling]
+#pod 	directories = docs
+#pod 	wordlist = Pod::Wordlist
+#pod 	spell_cmd = aspell list
+#pod 	stopwords = CPAN
+#pod 	stopwords = github
+#pod 	stopwords = stopwords
+#pod 	stopwords = wordlist
+#pod
+#pod If you're using C<[ExtraTests]> it must come after C<[Test::PodSpelling]>,
+#pod it's worth noting that this ships in the C<[@Basic]> bundle so you may have to
+#pod remove it from that first.
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing
+#pod the following file:
+#pod
+#pod   xt/author/pod-spell.t - a standard Test::Spelling test
+#pod
+#pod L<Test::Spelling> will be added as a develop prerequisite.
+#pod
+#pod =method add_stopword
+#pod
+#pod Called to add stopwords to the stopwords array. It is used to determine if
+#pod automagically detected words are valid and print out debug logging for the
+#pod process.
+#pod
+#pod =attr directories
+#pod
+#pod Additional directories you wish to search for POD spell checking purposes.
+#pod C<bin> and C<lib> are set by default.
+#pod
+#pod =attr wordlist
+#pod
+#pod The module name of a word list you wish to use that works with
+#pod L<Test::Spelling>.
+#pod
+#pod Defaults to L<Pod::Wordlist>.
+#pod
+#pod =attr spell_cmd
+#pod
+#pod If C<spell_cmd> is set then C<set_spell_cmd( your_spell_command );> is
+#pod added to the test file to allow for custom spell check programs.
+#pod
+#pod Defaults to nothing.
+#pod
+#pod =attr stopwords
+#pod
+#pod If stopwords is set then C<add_stopwords( E<lt>DATAE<gt> )> is added
+#pod to the test file and the words are added after the C<__DATA__>
+#pod section.
+#pod
+#pod C<stopwords> can appear multiple times, one word per line.
+#pod
+#pod Normally no stopwords are added by default, but author names appearing in
+#pod C<dist.ini> are automatically added as stopwords so you don't have to add them
+#pod manually just because they might appear in the C<AUTHORS> section of the
+#pod generated POD document. The same goes for contributors listed under the
+#pod 'x_contributors' field on your distributions META file.
+#pod
+#pod =begin Pod::Coverage
+#pod
+#pod mvp_multivalue_args
+#pod munge_files
+#pod munge_file
+#pod register_prereqs
+#pod
+#pod =end Pod::Coverage
+#pod
+#pod =head1 SUPPORT
+#pod
+#pod =for stopwords irc
+#pod
+#pod Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginTest-PodSpelling>
+#pod (or L<bug-Dist-Zilla-Plugin-Test-PodSpelling@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Test-PodSpelling@rt.cpan.org>).
+#pod I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+#pod
+#pod =cut
+
 =pod
 
 =encoding UTF-8
@@ -179,7 +270,7 @@ Dist::Zilla::Plugin::Test::PodSpelling - Author tests for POD spelling
 
 =head1 VERSION
 
-version 2.006008
+version 2.006009
 
 =head1 SYNOPSIS
 
@@ -261,48 +352,13 @@ munge_files
 munge_file
 register_prereqs
 
-=head1 BUGS
+=head1 SUPPORT
 
-Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/dist-zilla-plugin-test-podspelling/issues
+=for stopwords irc
 
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 CONTRIBUTORS
-
-=over 4
-
-=item *
-
-Alexandr Ciornii <alexchorny@gmail.com>
-
-=item *
-
-Breno G. de Oliveira <garu@cpan.org>
-
-=item *
-
-David Golden <dagolden@cpan.org>
-
-=item *
-
-Graham Knop <haarg@haarg.org>
-
-=item *
-
-Harley Pig <harleypig@gmail.com>
-
-=item *
-
-Karen Etheridge <ether@cpan.org>
-
-=item *
-
-Randy Stauner <rwstauner@cpan.org>
-
-=back
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginTest-PodSpelling>
+(or L<bug-Dist-Zilla-Plugin-Test-PodSpelling@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Test-PodSpelling@rt.cpan.org>).
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
 =head1 AUTHORS
 
@@ -320,12 +376,48 @@ Marcel Gruenauer <hanekomu@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Caleb Cushing.
+This software is Copyright (c) 2015 by Caleb Cushing.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge Randy Stauner Graham Knop David Golden Harley Pig Alexandr Ciornii Breno G. de Oliveira
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Randy Stauner <rwstauner@cpan.org>
+
+=item *
+
+Graham Knop <haarg@haarg.org>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=item *
+
+Harley Pig <harleypig@gmail.com>
+
+=item *
+
+Alexandr Ciornii <alexchorny@gmail.com>
+
+=item *
+
+Breno G. de Oliveira <garu@cpan.org>
+
+=back
+
 =cut
 
 __DATA__
